@@ -10,7 +10,7 @@ use Readonly;
 # Constants.
 Readonly::Scalar my $LAST_INDEX => -1;
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 # Constructor.
 sub new {
@@ -113,6 +113,7 @@ __END__
 =head1 SYNOPSIS
 
  use Tags::Utils::Preserve;
+
  my $obj = Tags::Utils::Preserve->new(%params);
  my $preserved_flag = $obj->begin;
  my ($preserver_flag, $prev_preserved_flag) = $obj->begin;
@@ -237,7 +238,7 @@ Install the Tags modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Tags>
+L<https://github.com/michal-josef-spacek/Tags>
 
 =head1 AUTHOR
 
@@ -247,11 +248,12 @@ L<http://skim.cz/>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2005-2018 Michal Josef Špaček
- BSD 2-Clause License
+© 2005-2020 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.07
+0.08
 
 =cut
